
from .logical import TRUE, true, T, FALSE, F, false, NULL
from .little import is_number, is_odd, is_even

from .r_funcs import nrow, ncol, colMeans, rowMeans, colSums, rowSums, apply, lapply, sapply, sample, sample_int

from .useful_funcs import fast_sample, randomTrue



from .other import time_to_seconds


